#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

newproperty(:blocked) do
  include EasyType

  desc <<-DESC
  When set to `true`, prevents the fact or fact group from being resolved when Facter
  runs.

  Here is an example on how to use this:

        fact_config { 'my_fact':
          blocked => truem
        }

  This will block fact `my_fact` on this node, meaning it will not be resolved.

  DESC

  data_type('Boolean')

  defaultto false
  newvalues(true, false)

  to_translate_to_resource do |raw_resource|
    raw_resource[:blocked]
  end

  def insync?(is)
    is = false if is == :absent
    is == should
  end

  def current_value
    resource.current_config&.dig('blocklist') || []
  end

  on_modify do
    new_value = if value.to_s == 'false'
                  current_value - [resource.name]
                else
                  current_value + [resource.name]
                end
    resource.config_doc = resource.config_doc.set_config_value('facts.blocklist',
                                                               Hocon::ConfigValueFactory.from_any_ref(new_value))
  end
end
