# frozen_string_literal: true

newproperty(:ttl) do
  include EasyType

  desc <<-DESC
  Specify the TTL for the cached value of the the specified fact.

  Values can be for example:

  - `30 days`
  - `6 hours`
  - `10 minutes`

  Here is an example on how to use this:

        fact_config { 'my_fact':
          ttl => '30 minutes',
        }

  This will set the ttl for fact `my_fact` to 30  minutes.

  DESC

  data_type("Variant[Enum['absent'],String[1]]")

  to_translate_to_resource do |raw_resource|
    raw_resource[:ttl]
  end

  def current_value
    resource.current_config&.dig('ttls') || []
  end

  def insync?(is)
    return true if (should == 'absent') && (is == :absent)

    super
  end

  on_modify do
    new_value = if value.to_s == 'absent'
                  current_value.delete_if { |e| e.key?(resource.name) }
                else
                  current_value << { resource.name => value }
                end
    resource.config_doc = resource.config_doc.set_config_value('facts.ttls',
                                                               Hocon::ConfigValueFactory.from_any_ref(new_value))
  end
end
